#
# spec file for package apache2-mod_perl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname mod_perl
Name:           apache2-mod_perl
Version:        2.0.13
Release:        1.3
Summary:        Embedded Perl for Apache
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://perl.apache.org/
Source0:        https://archive.apache.org/dist/perl/%{srcname}-%{version}.tar.gz
Source1:        https://archive.apache.org/dist/perl/%{srcname}-%{version}.tar.gz.asc
Source2:        https://www.apache.org/dist/perl/KEYS#/%{name}.keyring
Patch1:         avoid-broken-provides.diff
# bsc#1091625, workaround, according to mls it should be solved in perl
Patch2:         apache2-mod_perl-prctl-short-name.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  db-devel
BuildRequires:  ed
BuildRequires:  netcfg libnss_usrfiles2
BuildRequires:  pcre-devel
BuildRequires:  perl
BuildRequires:  perl-BSD-Resource
BuildRequires:  perl-Compress-Zlib
BuildRequires:  perl-Tie-IxHash
BuildRequires:  perl-libwww-perl
BuildRequires:  sudo
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
Requires:       perl = %{perl_version}
Requires:       perl-HTML-Parser
Requires:       perl-Tie-IxHash
Requires:       perl-URI
Requires:       perl-libwww-perl
Requires:       perl(Linux::Pid)
Conflicts:      mod_perl
Obsoletes:      mod_perl_2

%description
The Apache/Perl integration project brings together the full power of
the Perl programming language and the Apache HTTP server.

With mod_perl, it is possible to write Apache modules entirely in Perl.
The persistent interpreter embedded in the server avoids the overhead
of starting an external interpreter and the penalty of Perl start-up
time.

Note that you do not need mod_perl to run perl scripts via the common
gateway interface (CGI). mod_perl enables you to run Perl scripts in an
embedded interpreter if the additional performance is needed, but may
require modifications to the scripts.

%package devel
Summary:        Embedded Perl for Apache - Development package
Group:          Development/Languages/Perl
Requires:       %{name} = %{version}

%description devel
The Apache/Perl integration project brings together the full power of
the Perl programming language and the Apache HTTP server.

This package contains the include files useful for developing new
software depending on apache2-mod_perl.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor MP_APXS=%{apache_apxs} MP_APR_CONFIG=%{_bindir}/apr-1-config MP_CCOPTS="%{apache_cflags} -fgnu89-inline"
make %{?_smp_mflags}

%check
%if !0%{?qemu_user_space_build}
mkdir t/run
t/TEST -start-httpd -port select -startup_timeout 720
t/TEST -run-tests || true
t/TEST -stop-httpd
%endif

%install
%perl_make_install
# install /srv/www/perl-lib
install -d %{buildroot}/%{apache_serverroot}/perl-lib
# install /etc/apache2/conf.d/mod_perl.conf
install -d %{buildroot}/%{apache_sysconfdir}/conf.d
cat > %{buildroot}/%{apache_sysconfdir}/conf.d/mod_perl.conf <<EOF
<Directory "%{apache_serverroot}/perl-lib">
    AllowOverride None
    Options None
    <IfModule !mod_authz_host.c>
      Order allow,deny
      Deny from all
    </IfModule>
    <IfModule mod_authz_host.c>
      Require all granted
    </IfModule>
</Directory>
<IfModule mod_perl.c>
    PerlRequire "%{_sysconfdir}/apache2/mod_perl-startup.pl"
    ScriptAlias /perl/ "%{apache_serverroot}/cgi-bin/"
    <Location /perl/>
	# mod_perl mode
	SetHandler perl-script
	PerlResponseHandler ModPerl::Registry
	PerlOptions +ParseHeaders
	Options +ExecCGI
    </Location>
    ScriptAlias /cgi-perl/ "%{apache_serverroot}/cgi-bin/"
    <Location /cgi-perl>
	# perl cgi mode
	SetHandler  perl-script
	PerlResponseHandler ModPerl::PerlRun
	PerlOptions +ParseHeaders
	Options +ExecCGI
    </Location>
    # The /cgi-bin/ ScriptAlias is already set up in httpd.conf
</IfModule>
EOF
# install /etc/apache2/mod_perl-startup.pl
cat > %{buildroot}/%{apache_sysconfdir}/mod_perl-startup.pl <<-EOF
  # Taken from http://perl.apache.org/docs/2.0/user/handlers/server.html#Startup_File
  if ( ! \$ENV{MOD_PERL}) { die "GATEWAY_INTERFACE not Perl!"; }
  use lib qw(/srv/www/perl-lib);
  # enable if the mod_perl 1.0 compatibility is needed
  # use Apache2::compat ();
  # preload all mp2 modules
  # use ModPerl::MethodLookup;
  # ModPerl::MethodLookup::preload_all_modules();
  use ModPerl::Util (); #for CORE::GLOBAL::exit
  use Apache2::RequestRec ();
  use Apache2::RequestIO ();
  use Apache2::RequestUtil ();
  use Apache2::ServerRec ();
  use Apache2::ServerUtil ();
  use Apache2::Connection ();
  use Apache2::Log ();
  use APR::Table ();
  use ModPerl::Registry ();
  use Apache2::Const -compile => ':common';
  use APR::Const -compile => ':common';
  1;
EOF
# install documentation files alongside perl modules, where applicable
cp -av docs/api/*.pod %{buildroot}/%{perl_vendorarch}/
cp -av docs/api/APR/*.pod %{buildroot}/%{perl_vendorarch}/APR/
cp -av docs/api/Apache2/*.pod %{buildroot}/%{perl_vendorarch}/Apache2/
cp -av docs/api/ModPerl/*.pod %{buildroot}/%{perl_vendorarch}/ModPerl/
### since 11.4 perl_process_packlist
### removes .packlist, perllocal.pod files
%if 0%{?suse_version} > 1130
%perl_process_packlist
%else
# do not perl_process_packlist
# remove .packlist file
find %{buildroot}%{perl_vendorarch}/auto -name .packlist -print0 | xargs -0 -r rm ;
# remove perllocal.pod file
rm -f %{buildroot}%{perl_archlib}/perllocal.pod
%endif

# taken from kdump/kdump.spec, thanks!
# Compatibility cruft
# there is no %%license prior to SLE12
%if %{undefined _defaultlicensedir}
%define license %doc
%else
# filesystem before SLE12 SP3 lacks /usr/share/licenses
%if 0%(test ! -d %{_defaultlicensedir} && echo 1)
%define _defaultlicensedir %{_defaultdocdir}
%endif
%endif
# End of compatibility cruft

%files
%license LICENSE
%doc Changes README RELEASE STATUS
%doc docs
%dir %{apache_libexecdir}
%{apache_libexecdir}/mod_perl.so
%config(noreplace) %{apache_sysconfdir}/mod_perl-startup.pl
%config(noreplace) %{apache_sysconfdir}/conf.d/mod_perl.conf
%dir %{apache_serverroot}/perl-lib
%{_mandir}/man3/*
%{perl_vendorarch}/Apache
%{perl_vendorarch}/Apache2
%{perl_vendorarch}/APR
%{perl_vendorarch}/APR.pm
%{perl_vendorarch}/Bundle
%{perl_vendorarch}/ModPerl
%{perl_vendorarch}/auto/*
%{perl_vendorarch}/mod_perl2.pm
%{perl_vendorarch}/*.pod
%{_bindir}/mp2bug

%files devel
%{apache_includedir}/*

%changelog
* Mon Nov 13 2023 David Anes <david.anes@suse.com>
- Update to 2.0.13:
  * Use get_server_banner() instead of deprecated get_server_version() in
    Apache2::Status.
  * Avoid generating APR precompiled headers.
  * Fix build for perl >= 5.37.1.
- Removed apache2-mod_perl-perl-5.38.patch (fix already upstream)
* Tue Aug  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add apache2-mod_perl-perl-5.38.patch: Fix build with Perl 5.38.
  Usptream rev 1910623.
* Thu Apr 21 2022 David Anes <david.anes@suse.com>
- update to 2.0.12:
  * Add bug tracker information to README, and add CONTRIBUTING.md.
  * Fix detection of APR's threading support on RHEL 8.
  * Fix build for perl >= 5.33.7.
  * Fix SIGSEGV crash due to wrong use of perl_parse().
  * Improve installation instructions for AIX.
- remove patch:
  * fix_perl_5.34_build.patch (there is a fix already upstreamed)
- refreshed patches:
  * avoid-broken-provides.diff
  * apache2-mod_perl-prctl-short-name.patch
* Mon Sep 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- fix build error with fix_perl_5.34_build.patch
* Thu Feb 13 2020 pgajdos@suse.com
- define %%license for older codestreams
* Sat Nov 16 2019 Andreas Stieger <andreas.stieger@gmx.de>
- Apache mod_perl 2.0.11:
  * CVE-2011-2767: Arbitrary Perl code execution in the context of
    the user account via a user-owned .htaccess (boo#1156944)
* Tue Jul 17 2018 pgajdos@suse.com
- restore process name after sv_setpv_mg() call [bsc#1091625]
  + apache2-mod_perl-prctl-short-name.patch
* Fri Dec 30 2016 astieger@suse.com
- update to 2.0.10:
  * Automatically select the appropriate c89 option when modperl is
    being built with either gcc 5 or clang
  * Fix non-threaded Perl 5.22.x build and tests
  * Add support for Perl 5.22.x
    drop upstreamed mod_perl-add_support_for_perl_5.22.patch
* Mon Oct  3 2016 tchvatal@suse.com
- Remove unused icon and shorten the description a bit 1-2 migration
  is quite irelevant in these days
- Move tests to %%check  phase
- Use proper group for devel subpackage
* Wed Dec 16 2015 vcizek@suse.com
- fix mod_perl with perl 5.22 (boo#945195)
  * add mod_perl-add_support_for_perl_5.22.patch
* Thu Aug 13 2015 schwab@suse.de
- Remove apache2 packaging bug workaround
* Tue Aug  4 2015 schwab@suse.de
- Force gnu89 inline semantics
- Disable tests only in QEMU user-space builds
- inline.patch: remove
* Tue Jul 28 2015 pgajdos@suse.com
- updated to 2.0.9: see Changes for details
  * dropped patches:
  - lfs-perl-5.14.patch
  - apache2-mod_perl-2.0.4-tests.diff
  - apache24-mod_authz_host.patch
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Jun 26 2015 tjcw@physics.org
- turn off inlining for functions which need to be real symbols because they
  are called in a DSO
  * added inline.patch
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Wed Sep 17 2014 jsegitz@suse.com
- Changed access control statements in config file to use
  mod_authz_host (bnc#897005)
* Tue Sep  9 2014 vcizek@suse.com
- adapt test configuration for apache24 to fix build
  * use the new access control mechanisms from apache24
  * added apache24-mod_authz_host.patch
* Mon Jul 21 2014 vcizek@suse.com
- Linux::Pid is required by Apache2-SizeLimit (bnc#888117)
* Mon Aug  5 2013 coolo@suse.com
- add avoid-broken-provides.diff to avoid package providing
  HTTP::Request::Common, which it does not (only for testing)
* Tue Jul 16 2013 ro@suse.de
- change testsuite setup to fix build on factory:
  - do not load access_compat_module as it is builtin
  - do not load unixd_module as it is builtin
* Tue Jun 25 2013 coolo@suse.com
- update to version 2.0.8 (http24 branch as used by debian):
  Perl 5.16.3's fix for a rehash-based DoS makes it more difficult to invoke
  the workaround for the old hash collision attack, which breaks mod_perl's
  t/perl/hash_attack.t. Patch from rt.cpan.org #83916 improves the fix
  previously applied as revision 1455340. [Zefram]
  On Perl 5.17.6 and above, hash seeding has changed, and HvREHASH has
  disappeared. Patch to update mod_perl accordingly from rt.cpan.org #83921.
  [Zefram]
  Restore build with Perl 5.8.1, 5.8.2 etc: take care to use
  $Config{useithreads} rather than $Config{usethreads}, and supply definitions
  of Newx and Newxz as necessary. [Steve Hay]
  On Perl 5.17.9, t/apache/read2.t fails because an "uninitialized value"
  warning is generated for the buffer being autovivified. This is because
  the sv_setpvn() that's meant to vivify the buffer doesn't perform set
  magic; the warning is generated by the immediately following SvPV_force().
  Patch to fix this from rt.cpan.org #83922. [Zefram]
  Fix t/perl/hash_attack.t to work with Perl 5.14.4, 5.16.3 etc, which
  contain a fix for CVE-2013-1667 (memory exhaustion with arbitrary hash
  keys). This resolves rt.perl.org #116863, from where the patch was taken.
  [Hugo van der Sanden]
  use APR::Finfo instead of Perl's stat() in ModPerl::RegistryCooker to
  generate HTTP code 404 even if the requested filename contains newlines
  [Torsten]
- disable patch lfs-perl-5.14.patch as it no longer applies, but
  I can't find out if it's still need for ppc64 or if upstream's
  changes are good enough
* Sat Apr  6 2013 dimstar@opensuse.org
- Update to version 2.0.7+svn1448242 (http24 branch):
  + Fix build with Apache 2.4.
- Update to version 2.0.7:
  + Fix breakage caused by removal of PL_uid et al from perl 5.16.0.
- Drop patch-PL_uid.diff: fixed upstream.
- Adjust extra.conf setup for the test suite: include the
  nescessary modules needed to have a valid configuration for the
  test server: access_compat_module, authn_core_module,
  authz_core_module and unixd_module.
* Thu Oct 11 2012 coolo@suse.com
- buildrequire netcfg explicitly
* Thu May 31 2012 coolo@suse.com
- update to 2.0.6
  +Set the -apxs argument correctly when building from mod_perl.
  [Steve Hay]
  +Doc spelling fix
  [Nicholas Bamber]
  +Add Apache-Test 1.34 dependency.
  [Phred]
* Wed Feb 22 2012 dvaleev@suse.com
- do lfs. Fixes ppc64 build
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu May 26 2011 coolo@novell.com
- avoid a conflict between apache's LARGEFILE64_SOURCE and perl's
  FILE_OFFSET_BITS=64 because the conflict isn't real and causes
  the perl structures to be invalid if only the apache flags are used
* Wed May 18 2011 coolo@novell.com
- update to 2.0.5
  * Prepare modperl for the upcoming perl 5.14
  * Many other fixes over two years, see Changes
* Mon Dec 20 2010 vcizek@novell.com
- bnc#495434 (cve-2009-0796)
* Thu Nov 25 2010 chris@computersalat.de
- fix perl_process_packlist stuff
  o remove .packlist, perllocal.pod files
- cleanupo spec
  o replace 'mkdir -p' with 'install -d' or 'install -D'
  o macros
* Fri Mar  5 2010 coolo@novell.com
- fix one issue with start-httpd
- comment out test suite
* Thu Nov  6 2008 anicka@suse.cz
- temporarily disable two tests that fail due to the bug
  in Apache-Test
* Fri Jun 27 2008 anicka@suse.cz
- update to 2.0.4
  * Refactor tests to use keepalives instead of same_interp
  * Apache2::Reload has been moved to an externally maintained
  CPAN distribution
  * Expose apr_thread_rwlock_t with the APR::ThreadRWLock module
  * Catch up with some httpd API changes
  * SECURITY: CVE-2007-1349 (cve.mitre.org)
  fix unescaped variable interprolation in regular expression
  fix ModPerl::RegistryCooker::read_script to handle all
  possible errors, previously there was a case where
  Apache2::Const::OK was returned on an error.
  * bugfixes
- enable test suite
* Tue Jan 15 2008 ro@suse.de
- update to SVN version to build with current perl
- still ignore test-suite errors for the moment
* Thu Jun 14 2007 anicka@suse.cz
- split up devel subpackage
* Tue Jan 23 2007 anicka@suse.cz
- update to 2.0.3
  * Prevent things in %%INC that are not stat() able
    from breaking Apache2::Status 'Loaded Modules'
    under fatal warnings.
  * Multi-line $PerlConfig is now working
  * Fixed problems with add_config() and thread-safety
  * Added support for httpd-2.2's new override_opts in
    Apache2::Access. Calls to add_config() now accept
    an override_opts value as the 4th argument.
  * more minor fixes and improvements
- remove last two patches (fixed in upstream)
- temporarily disable t/api/server_const.t because
  it does not work with current get_server_version()
* Wed Aug  9 2006 poeml@suse.de
- build fix for sles9: add openldap2-devel to BuildRequires
* Fri Jul 14 2006 olh@suse.de
- rename gzip archive from .bz2 to .gz
* Tue Jul  4 2006 poeml@suse.de
- add mod_perl-r411028-t_api_status.patch and
  mod_perl-t_content_length-r412063.patch, which both fix test
  cases to work with httpd trunk
- remove SOL_IPV6-test.c and mod_perl-1.99_09-ipv6.dif, which have
  not been needed for long enough now
- enable more apache modules in testing (deflate, proxy,
  proxy_http)
* Mon Jan 30 2006 poeml@suse.de
- removed libapr-util1-devel from BuildRequires (apache2-devel does
  require it)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 21 2005 varkoly@suse.de
- Update to 2.0.2
* Mon Dec 12 2005 poeml@suse.de
- fix quoting of dollar sign in here document which creates the
  startup file [#136882]
* Tue Nov 15 2005 uli@suse.de
- disabled tests on ARM, don't make much sense with current QEMU
* Fri Aug 12 2005 poeml@suse.de
- install documentation [#95243]
* Tue Aug  2 2005 pth@suse.de
- mod_perl2 needs a different startup file (#99275)
* Wed Jul 27 2005 pth@suse.de
- Update to 2.0.1
* Tue Jan 25 2005 poeml@suse.de
- update 2.0.0 to release candidate 4
- move usage hints from %%post into package description
- remove obsolete stuff from %%clean
* Mon Dec 20 2004 poeml@suse.de
- update to 2.0.0, release candidate 1
- comment out mod_perl-1.99_09-ipv6.dif, it shouldn't be needed
  anymore for the build farm
- the call to /usr/share/apache2/get_module_list is not needed
- fix startup file for recent changes
* Mon Oct 11 2004 poeml@suse.de
- update to 1.99_15_20040907
- put Apache-Test in separate tarball
* Tue Mar  2 2004 poeml@suse.de
- update to CVS snapshot 1.99_12_20040302
- two tests need small tweaks for file permissions
- mod_perl-1.99_09-perlmm.dif is obsolete
- remove file ROADMAP from filelist
* Thu Feb 19 2004 ro@suse.de
- added check-build.sh (build on 2.6 hosts only)
* Wed Jan 28 2004 ro@suse.de
- build as normal user
* Tue Nov 18 2003 poeml@suse.de
- add some comments about the SOL_IPV6-test.c test program [#31246]
* Mon Sep 22 2003 mls@suse.de
- fix build for official perl-5.8.1 (missing MM initialization)
* Thu Aug 28 2003 poeml@suse.de
- last added patch is not needed
- clean up some old cruft from the spec file
- use only IPv4 sockets for testing, if SOL_IPV6 socket option is
  not available. With this the package builds on all machines.
* Thu Aug 21 2003 mjancar@suse.cz
- honor user supplied OPTIMIZE like original MakeMaker does
- use $RPM_OPT_FLAGS
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 poeml@suse.de
- update to snapshot 1.99_09_20030803
- enable t/apr-ext/uuid.t (problem was that apr-config wasn't found)
- add db-devel to neededforbuild, so APR.so can be linked with
  `apu-config --ldflags --libs`
* Wed Aug  6 2003 poeml@suse.de
- fix last change: config-dist.sh did never exit with "ok"
* Tue Aug  5 2003 ro@suse.de
- use different string in config-dist.sh (one we check for ...)
* Mon Aug  4 2003 poeml@suse.de
- config-dist.sh: build only on hosts that support listening on
  IPv6-only sockets
- increase the timeout when waiting for the test server.
- add extra precautions to stop test server. The start can hang if
  the random device blocks, and when no pid file has been written
  the testsuite will not kill it
- don't make use of %%jobs, it doesn't work
- obsolete mod_perl_2, the precursor
- fix typo in %%post
* Mon Aug  4 2003 poeml@suse.de
- update to snapshot 1.99_09_20030803
- disable a new test that fails
- add a diagnostic config-dist.sh
* Sun Jul 27 2003 poeml@suse.de
- update to snapshot 1.99_09_20030727
- add sudo to the buildsystem, so the tests can be run as nobody
- don't explicitely strip binaries since RPM handles it, and may
  keep the stripped information somewhere
- add perl-Compress-Zlib to the buildsystem (for another test)
- CFLAGS can be taken from apxs -q CFLAGS, and they'll match. It's
  better not to miss _FILE_OFFSET_BITS=64
- allow passing of "jobs" define from rpm for make -j
- install with install_vendor target, and use %%{perl_vendorarch}
  macro
* Tue Jul  1 2003 ro@suse.de
- use perl_process_packlist macro
* Tue Jun 17 2003 poeml@suse.de
- add missing directories
- add a hint on how to configure mod_perl
* Tue Jun 10 2003 poeml@suse.de
- update to 2.0_20030610110118 snapshot (called 1.99_09_20030610)
* Fri Feb 28 2003 poeml@suse.de
- make the test suite pass again, by renaming two .pl files of the
  test suite to .shtml, because mod_include didn't include files
  other than .shtml any longer
* Wed Feb 12 2003 poeml@suse.de
- rename package from mod_perl_2 to apache2-mod_perl
* Tue Feb 11 2003 poeml@suse.de
- call the new apache configuration script, so modules that are
  needed for the test get loaded
* Mon Feb 10 2003 poeml@suse.de
- MPM specific links to mod_dav_svn.so are no longer needed
- add apache_libexecdir to filelist
* Tue Jan 14 2003 poeml@suse.de
- update to 1.99_08
  - <Perl> directive missing closing '>' bug fixed, and much else
- drop /etc/apache2/modules/mod_perl
- add /etc/apache2/mod_perl-startup.pl, setting up with
  /srv/www/perl-lib in @INC
- add /etc/apache2/conf.d/mod_perl.conf, setting up scriptaliases
  /perl/, and /cgi-perl/ (for unaltered CGI scripts under mod_perl)
- use %%defattr
* Wed Dec  4 2002 poeml@suse.de
- update to 1.99_07
- build one module, it works for all MPMs
- use RPM_OPT_FLAGS
* Fri Aug 30 2002 poeml@suse.de
- new package with mod_perl-1.99_05 for Apache 2
